.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

=============
acentoweb.ecv
=============

Exports ECV files from Plone CMS


Features
--------

- View to export ECV files  


 


Documentation
-------------

Full documentation for end users can be found in the "docs" folder, and is also available online at http://docs.plone.org/foo/bar


Translations
------------

This product has been translated into

- english (default=)


Installation
------------

Install acentoweb.ecv by adding it to your buildout::

    [buildout]

    ...

    eggs =
        acentoweb.ecv


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/espenmn/acentoweb.ecv/issues
- Source Code: https://github.com/espenmn/acentoweb.ecv



Support
-------

If you are having issues, please let us know.
espen@medialog.no


License
-------

The project is licensed under the GPLv2.
